@@ -24,18 +24,18 @@ use Daje::Workflow::Errors::Error;
 #
 #    my $context->{context}->{some_key_needed_by_some_activity}="";
 #
-#    my $context->{context}-{workflow}->{workflow} = "Workflow name";
+#    my $context->{context}->{workflow}->{workflow} = "Workflow name";
 #
-#    my $context->{context}-{workflow}->{activity} = "Name of activity";
+#    my $context->{context}->{workflow}->{activity} = "Name of activity";
 #
-#    my $context->{context}-{workflow}->{workflow_pkey} = "If not 0 workflow will be loaded";
+#    my $context->{context}->{workflow}->{workflow_pkey} = "If not 0 workflow will be loaded";
 #
 #    If workflow_pkey == 0 but connector_fkey > 0 and connector != "" connector data will
 #    be used to try to load the workflow. If no workflow is found a new will be created.
 #
-#    my $context->{context}-{workflow}->{connector_fkey} = Number;
+#    my $context->{context}->{workflow}->{connector_fkey} = Number;
 #
-#    my $context->{context}-{workflow}->{connector} = "If not 0 workflow will be loaded";
+#    my $context->{context}->{workflow}->{connector} = "If not 0 workflow will be loaded";
 #
 #
 #    my $workflow = Daje::Workflow->new(
@@ -52,7 +52,25 @@ use Daje::Workflow::Errors::Error;
 # DESCRIPTION
 # ===========
 #
-# Daje::Workflow is
+# Daje::Workflow is Just a Bunch of States
+# A workflow is just a bunch of states with rules on how to move between them.
+# These are known as transitions and are triggered by some sort of event.
+# A state is just a description of object properties. You can describe a
+# surprisingly large number of processes as a series of states and
+# actions to move between them.
+#
+# When you create a workflow you normally have only one action available to you.
+# The workflow has a state 'INITIAL'
+# when it is first created, but this is just a bootstrapping
+# exercise since the workflow must always be in some state.
+#
+# Every workflow action has a property 'resulting_state', which just means:
+# if you execute me properly the workflow will be in the new state.
+#
+# All this talk of 'states' and 'transitions' can be confusing, but just match
+# them to what happens in real life -- you move from one action to another and
+# at each step ask: what happens next?
+#
 #
 # LICENSE
 # =======
@@ -67,7 +85,7 @@ use Daje::Workflow::Errors::Error;
 # janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
 #
 
-our $VERSION = "0.16";
+our $VERSION = "0.18";
 
 has 'workflow_name';    #
 has 'workflow_pkey';    #
@@ -233,6 +251,7 @@ __END__
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -252,18 +271,18 @@ Daje::Workflow - It's a simple workflow engine
 
    my $context->{context}->{some_key_needed_by_some_activity}="";
 
-   my $context->{context}-{workflow}->{workflow} = "Workflow name";
+   my $context->{context}->{workflow}->{workflow} = "Workflow name";
 
-   my $context->{context}-{workflow}->{activity} = "Name of activity";
+   my $context->{context}->{workflow}->{activity} = "Name of activity";
 
-   my $context->{context}-{workflow}->{workflow_pkey} = "If not 0 workflow will be loaded";
+   my $context->{context}->{workflow}->{workflow_pkey} = "If not 0 workflow will be loaded";
 
    If workflow_pkey == 0 but connector_fkey > 0 and connector != "" connector data will
    be used to try to load the workflow. If no workflow is found a new will be created.
 
-   my $context->{context}-{workflow}->{connector_fkey} = Number;
+   my $context->{context}->{workflow}->{connector_fkey} = Number;
 
-   my $context->{context}-{workflow}->{connector} = "If not 0 workflow will be loaded";
+   my $context->{context}->{workflow}->{connector} = "If not 0 workflow will be loaded";
 
 
    my $workflow = Daje::Workflow->new(
@@ -282,7 +301,25 @@ Daje::Workflow - It's a simple workflow engine
 =head1 DESCRIPTION
 
 
-Daje::Workflow is
+Daje::Workflow is Just a Bunch of States
+A workflow is just a bunch of states with rules on how to move between them.
+These are known as transitions and are triggered by some sort of event.
+A state is just a description of object properties. You can describe a
+surprisingly large number of processes as a series of states and
+actions to move between them.
+
+When you create a workflow you normally have only one action available to you.
+The workflow has a state 'INITIAL'
+when it is first created, but this is just a bootstrapping
+exercise since the workflow must always be in some state.
+
+Every workflow action has a property 'resulting_state', which just means:
+if you execute me properly the workflow will be in the new state.
+
+All this talk of 'states' and 'transitions' can be confusing, but just match
+them to what happens in real life -- you move from one action to another and
+at each step ask: what happens next?
+
 
 
 
